pro copy_gbl, flares, copy=copy, indir=indir, outdir=outdir
;
;+
;NAME:
;	copy_gbl
;PURPOSE:
;	To copy the VMS IDL GRO/BATSE light curve save files over, restore
;	them under VMS and save them with /XDR enabled with a different
;	file name so they can be sorted by time.
;METHOD:
;	Should be run on a VMS system because save files did not use /XDR
;	option
;HISTORY:
;	Written 15-Apr-93 by M.Morrison
;	19-Apr-93 (MDM) - Modified to also save UTB, XCRANGE, YCRANGE
;
;
if (n_elements(flares) eq 0) then flares = indgen(3881)+1	;all flares
if (n_elements(indir) eq 0) then indir = 'dsk1:[sxtimages.batse]
if (n_elements(outdir) eq 0) then outdir = 'nfs8:[yohkoh.morrison.batse_raw]
;
if (keyword_set(copy)) then begin
    for i=0,n_elements(flares)-1 do begin
	infil = 'isis::sys$data2:[batse.flares]flare_' + strtrim(flares(i), 2) + '.sav'
	cmd = 'copy ' + infil + ' *'
	print, cmd
	spawn, cmd, result
	prstr, result
    end
end
;
for i=0,n_elements(flares)-1 do begin
    filnam = 'flare_' + strtrim(flares(i), 2) + '.sav'
    infil = concat_dir(indir, filnam)
    if (file_exist(infil)) then begin
	print, 'Processing: ', infil
	restore, infil

	tim = flare_datacom.start_secs
	;;mipseb_dblfixup, tim  ;fix the double precision problem
	daytim = anytim2ex([((tim mod 86400))*1000, fix(tim/86400)+1])
	ofilnam = 'gbl' + ex2fid(daytim) + '_f' + string(flares(i), format='(i4.4)') + '_sav'

	outfil = concat_dir(outdir, ofilnam)
	print, outfil
	save, archive_sec, archive_data, flare_datacom, subtitle1, subtitle2, utb, xcrange, ycrange, /xdr, file=outfil
    end else begin
	print, infil, ' DOES NOT EXIST.  Skipping...'
    end
end
;
end
