;+
; NAME: 
;        dsk_locb
;
; PURPOSE:
;   To find the center and diameter of solar images. This is a crude 
;   version of using a histogram technique. For clean images it will
;   give quick results to within a pixel. 
;
; CALLING SEQUENCE:
;                    dsk_locb,image,[KEYWORD=variable,..]
;
; PARAMETER:	image	input optical image.
;
; KEYWORDS:
;
;          HORZCNT	horizontal center, floating point pixels.
;	   VERTCNT      vertical center, floating point pixels.
;	   HORZRAD      horizontal diameter, floating point pixels.
;	   VERTRAD      vertical diameter, floating point pixels.
; 	   EASTLIMB     east limb pixel index. 
;	   WESTLIMB     west limb pixel index.
;	   NPOLE        north pole pixel index.
;	   SPOLE        south pole pixel index.
;          CUT          cut off used to find limb.
;
; RETURN TYPE:
;
; HISTORY:  
;           drafted by A. Mcallister, Apr., 1992.
;           reworked to use cutoff and do sxt images crudely, may 1992.
;           decreased cutoff factor to handle KP MG's, Nov. 1992. A.McA.
;           reworked to handle negative numbers too, Dec. 1992. A.McA.
;           added CUT keyword to return cutoff value, Dec. 1992. A.McA.
;	    Modified to handle case of low contrast, 19-Apr-95 (MDM)
;-
pro dsk_locb,imgin,HORZCNT=cnthz,VERTCNT=cntvt,HORZRAD=rdhz,VERTRAD=rdvt, $
              EASTLIMB=mnhz,WESTLIMB=mxhz,NPOLE=mxvt,SPOLE=mnvt,CUT=cut

imgsz=size(imgin)
horz=fltarr(imgsz(1))
vert=fltarr(imgsz(2))

cut=cut_lev(imgin,imgsz)

;find max and min with straight cutoff

for i=0,imgsz(1)-1 do horz(i)=total(imgin(i,0:imgsz(2)-1)-cut)  ;only look above cut

hzmsk=where(horz gt 0)
if (hzmsk(0) eq -1) then hzmsk = where(horz-min(horz) ge 0.5*max(horz-min(horz)))	;MDM added 19-Apr-95
mnhz=min(hzmsk)			;lower edge of lower pixel
mxhz=max(hzmsk)			;upper edge of upper pixel

cnthz=float(mxhz+mnhz+1)/2.       ;add one to locate at pixel center

;print,mnhz,mxhz,cnthz

for i=0,imgsz(2)-1 do vert(i)=total(imgin(cnthz-15:cnthz+15,i)-cut)  ;look in narrow range

;find max and min with straight cutoff

vtmsk=where(vert gt 0)
if (vtmsk(0) eq -1) then vtmsk = where(vert-min(vert) ge 0.5*max(vert-min(vert)))	;MDM added 19-Apr-95
mnvt=min(vtmsk)
mxvt=max(vtmsk)

rdvt=float(mxvt-mnvt)
cntvt=float(mxvt+mnvt+1)/2            ;add one to locate at pixel center

;print,mnvt,mxvt,cntvt,rdvt

;go back and check horizontal again

for i=0,imgsz(1)-1 do horz(i)=total(imgin(i,cntvt-15:cntvt+15)-cut)  ;only look above cut

hzmsk=where(horz gt 0)
if (hzmsk(0) eq -1) then hzmsk = where(horz-min(horz) ge 0.5*max(horz-min(horz)))	;MDM added 19-Apr-95
mnhz=min(hzmsk)
mxhz=max(hzmsk)

rdhz=float(mxhz-mnhz)
cnthz=float(mxhz+mnhz+1)/2

;print,mnhz,mxhz,cnthz,rdhz

;this gives us the rough centroid, at least within the disk.

return
end	
