function get1gbo, prefix, time, head=head, dattim=dattim, correct=correct, $
		window=window, delta=delta, file=file, qstop=qstop, mask=mask, $
		site=site, scale=scale
;+
;NAME:
;	get1gbo
;PURPOSE:
;	To get a single GBO image closest to a given time
;SAMPLE CALLING SEQUENCE:
;	img = get1gbo('gkm', '1-sep-92')	;Kitt peak magnetogram
;	img = get1gbo('g*h', '1-jan-92')	;H-alpha from any site
;	img = get1gbo(['g*m', 'g*h'])		;latest mag or h-alpha any site
;INPUTS:
;	prefix	- The prefixes to use of the GBO file name
;OPTIONAL INPUT:
;	time	- The time of interest (want the closest GBO image to that time)
;OPTIONAL KEYWORD INPUT:
;	correct	- If set, then correct the image for limb darkening / plate
;		  scale size.
;			**** /CORRECT IS NOT AVAILABLE RIGHT NOW ****
;	window	- The window in days +/- the input time which is accecptable
;		  to match on an image
;	mask	- If set, then call GBO_MASK to mask out text written on the
;		  image.
;OUTPUT:
;	img	- The image as read from the file.  If there is no match on
;		  directories or prefixes, it returns a 0 byte.
;OPTIONAL KEYWORD OUTPUT:
;	file	- The GBO file name selected
;	head	- The FITS header for the image
;	dattim	- The date/time of the image selected (structure format)
;	delta	- The number of days between the requested time and the
;		  date/time of the image found
;	site	- Site string 
;	scale	- Passed to RFITS to scale the image
;HISTORY:
;	Written 20-Sep-94 by M.Morrison
;	20-Sep-94 (MDM) - Added SITE output
;	20-Sep-94 (MDM) - Added SCALE option
;	29-Sep-94 (MDM) - Expanded to use "gbd_list" instead of
;			  "gbd" alone.
;-
;
if (n_elements(prefix) eq 0) then prefix = 'g*'
if (n_elements(time) eq 0) then time = ut_time()
if (n_elements(window) eq 0) then window = 8	;+/- 8 days
;
tim1 = anytim2ints(time, off=-1*window*86400.)
tim2 = anytim2ints(time, off=   window*86400.)
anytim2weeks, tim1, tim2, wid, /string
base_dirs = getenv('gdb')
if (getenv('gdb_list') ne '') then base_dirs = str2arr(getenv('gdb_list'))
dirs = file_list(base_dirs, 'gbo'+wid+'a', /cd)
if (dirs(0) eq '') then begin
    print, 'No GBO image directories found for weeks ' + wid
    print, 'Returning...
    return, 0b
end
;
file = file_seltime(dirs, prefix, time, /closest)
if (file(0) eq '') then begin
    print, 'No files with prefix: ' + prefix + ' found in directories: ' + dirs
    print, 'Returning...
    return, 0b
end
;
print, 'GET1GBO: Reading ' + file + ' ....'
img = rfits2(file, head=head, scale=scale)
if (keyword_set(mask)) then img = gbo_mask(img)
break_file, file, dsk_log, dir, filnam, ext
fid = strmid(filnam, 3, 6) + strmid(ext, 0, 5)
dattim = anytim2ints( fid2ex(fid) )
delta = int2secarr(dattim, time) / 86400.
;
site = get_gol_site( strmid(filnam, 1, 1) )
;
if (abs(delta) gt window) then img = 0b
;
if (keyword_set(qstop)) then stop
return, img
end

