function get_gol_type, item
;
;+
;NAME:
;	get_gol_type
;PURPOSE:
;	Given a GBO Observing Log structure or a string array, return
;	a the description of the image type
;SAMPLE CALLING SEQUENCE:
;	a = get_gol_type(gol)
;	a = get_gol_type('h')
;INPUT:
;	item	- The input GOL structure or string
;OUTPUT:
;	a string array the same length as the input with the description
;	of the image type
;HISTORY:
;	Written 21-Apr-93 by M.Morrison
;-
;
if (n_elements(item) eq 0) then  begin
    help_prefix, 'gx_', /full
    return, ''
end
;
siz = size(item)
typ = siz( siz(0)+1 )
case typ of
    8: val = strupcase( strmid( string(item.st$image_type), 0, 1 ) )
    7: val = strupcase(item)
    else: begin
		message, 'Do not recognize the input variable type', /info
		return, ''
	  end
endcase
;
n = n_elements(item)
out = strarr(n) + 'Unknown'
ss = where(val eq 'C')	& if (ss(0) ne -1) then out(ss) = 'Large Scale H-Alpha
ss = where(val eq 'H')	& if (ss(0) ne -1) then out(ss) = 'H-alpha
ss = where(val eq 'I')	& if (ss(0) ne -1) then out(ss) = 'HeI 10830 A
ss = where(val eq 'K')	& if (ss(0) ne -1) then out(ss) = 'Calcium'
ss = where(val eq 'M')	& if (ss(0) ne -1) then out(ss) = 'Magnetogram
ss = where(val eq 'S')	& if (ss(0) ne -1) then out(ss) = 'Spectrohelioscope
ss = where(val eq 'W')	& if (ss(0) ne -1) then out(ss) = 'white light
ss = where(val eq 'X')	& if (ss(0) ne -1) then out(ss) = 'X-ray
;
return, out
end

