pro goes_log,input1,input2,			$
	file=file,append=append,result=result,	$
	fillsaa=fillsaa,fillnight=fillnight,refresh=refresh
;+
; NAME:
;  goes_log
; PURPOSE:
;  Click on a GOES plot and then return the values of 
;  Goes 6,7 in the low and high bands for the selected time.
; CALLING SEQUENCE:
;   (Run Plot_goes first)
;   goes_log,/file
;   goes_log,time1,time2,file=file
;   goes_log,time1,time2,file=file,/append,/refresh
;
; INPUTS:
;  None.
; OUTPUS:
;  None.
; OPTIONAL OUTPUT KEYWORDS:
;   file	= If set, write out to goes_log.dat
;   file = file	=> Write output to given filename
;   append	= If set, append to an existing file
;   refresh	= Refresh the GOES plot
;   fillsaa	= If set, fill in SAA if the GOES plot is refreshed
;   fillnight	= If set, fill in Night if the GOES plot is refreshed
;   result	= A string array of information
; MODIFICATION HISTORY:
;   11-dec-93, J. R. Lemen LPARL, Written
;-

if n_elements(input1) ne 0 then plot_goes,input1,input2,fillsaa=fillsaa,fillnight=fillnight

; Get the time base from the Goes plot (based on fem_grid):

getut, utbase=startt, /string			; Utplot common block read
stopf  = anytim2ints(startt,offset=!x.crange(1)); Last x.crange for stop
if keyword_set(refresh) and (n_elements(input1) eq 0)	$
	then plot_goes,startt,stopf,fillsaa=fillsaa,fillnight=fillnight

!quiet=0					; Make sure it is turned on
startf = anytim2ints(startt,offset=-4.*60.*60.)	; Back up two hours
stopf  = anytim2ints(startt,offset=!x.crange(1)); Last x.crange for stop
stopf  = anytim2ints(stopf, offset=4.*60.*60.)	; Add on two more hours

; Read the 1-minute data

rd_gxt,startf,stopf,gxr_rec
ss6 = where(gxr_rec.g6lo gt 0) & g6 = gxr_rec(ss6)
ss7 = where(gxr_rec.g7lo gt 0) & g7 = gxr_rec(ss7)

goes_converter,g6.g6lo,g6lo
goes_converter,g6.g6hi,g6hi
goes_converter,g7.g7lo,g7lo
goes_converter,g7.g7hi,g7hi

print,'Click on desired time with left button'
if keyword_set(file) then print,'Click on the middle button to elminate last point from file'
print,'Click on right button to exit'

repeat begin
  utcursor,x,y,err=err,/quiet
  if err eq 1 then begin
     evt_grid, x		; Mark with a vertical line
     i6 = tim2dset(g6,x)	; Index of closet time
     i7 = tim2dset(g7,x)	; Index of closet time
     str = string(fmt_tim(g6(i6)),g6lo(i6),g6hi(i6),	$
		  fmt_tim(g7(i7)),g7lo(i7),g7hi(i7),format='(a,2e9.2,4x,a,2e9.2)')
     print,str
  endif
  if err ne 4 then begin
     if err eq 2 then begin
	  if n_elements(buff) ne 0 then print,'Deleting last entry ...'
	  if n_elements(buff) le 1 then delvarx,buff	$
	  else buff = buff(0:n_elements(buff)-2)
     endif else if n_elements(buff) eq 0 then buff = str else buff = [buff, str]
  endif
endrep until err eq 4

if n_elements(buff) gt 0 then result = buff else delvarx,result
if keyword_set(file) and (n_elements(buff) gt 0) then begin
  sz = size(file)
  if sz(sz(0)+1) eq 7 then filnam = file else filnam = 'goes_log.dat'
  if n_elements(append) eq 0 then append = 0
  app = append
  if not file_exist(filnam) then app = 0
  openw,lun,filnam,/get_lun,append=append
  if not keyword_set(app) then begin
     printf,lun,'               ------- GOES 6 -------                   ------- GOES 7 -------'
     printf,lun,'Time (UT)            Low      High       Time (UT)            Low       High'
  endif else printf,lun,' '
  for i=0,n_elements(buff)-1 do printf,lun,buff(i),format='(a)'
  free_lun,lun
  text = ['written','appended']
  print,'Results ',text(keyword_set(append)),' to file: ',filnam
endif

end
