pro oplot_nts, yfst, yfh, nts=nts, color=color, qdebug=qdebug
;
;+
;NAME:
;	oplot_nts
;PURPOSE:
;	To overplot the Nobeyama correlation coefficient time series (NTS)
;SAMPLE CALLING SEQUENCE:
;	oplot_nts
;	oplot_nts, .6
;	oplot_nts, .6, .5
;OPTIONAL INPUT:
;	yfst	- The starting location on the plot in fractions (0 to 1)
;		  If not passed, it will use 0.75
;	yfh	- The height of the NTS plot in fractions (0 to 1)
;		  If not passed, it will use 0.23
;OPTIONAL KEYWORD OUTPUT:
;	nts	- The NTS data structure
;HISTORY:
;	Written 17-May-93 by M.Morrison
;-
;
COMMON UTCOMMON, UTBASE, UTSTART, UTEND, xst
;
if (n_elements(yfst) eq 0) then yfst = 0.75
if (n_elements(yfh) eq 0) then yfh = 0.23
;
sttim = anytim2ints(xst, off=!x.crange(0))
entim = anytim2ints(xst, off=!x.crange(1))
rd_nts, sttim, entim, nts, status=status
if (status gt 0) then begin
    message, 'No NTS data available for the time period from', /info
    message, fmt_tim(sttim) + ' to ' + fmt_tim(entim), /info
    return
end
;
imin = min(nts.coeff)
imax = max(nts.coeff)
dt = imax-imin
dy = !y.crange(1) - !y.crange(0)
y = (nts.coeff-imin)/dt * dy*yfh + !y.crange(0) + dy*yfst
xx = deriv_arr(int2secarr(nts))
ss = where(xx gt 1000)
;
if (ss(0) eq -1) then begin
    outplot, nts, y, color=color 
end else begin
    for i=0,n_elements(ss) do begin
	if (i eq 0) then ist=0 else ist = ss(i-1)+1
	if (i eq n_elements(ss)) then ien=n_elements(nts)-1 else ien = ss(i)
	outplot, nts(ist:ien), y(ist:ien), color=color
	if (keyword_set(qdebug)) then print, ist, ien
    end
end
;
if (keyword_set(qdebug)) then stop
end
