pro rd_guf_ascii, infile, uly_recs , week=week
;
;+
;   Name: rd_guf_ascii
;
;   Purpose: read Ulysses epehmeris file (ascii) and return Yohkoh structure
;
;   History:
;      10-Mar-1994 (SLF)
;       5-Apr-1994 (SLF) ascii format change
;-

common rd_guf_ascii_blk, file, timeint, contents

if not keyword_set(infile) then $
	infile=findfile(concat_dir('$DIR_ULY_RAW','Ave.traj*'))

if n_elements(file) eq 0 then begin
;   if not file_exist(infile) then begin
;      tbeep
;      message,/info,"Can't find Ulysses Ephemeris File: " + infile
;      return
;   endif
;  slf - 31-mar-1994 - a header line was added (no delimiter) to ascii files
;  so data is in file lines(1:*) - line(0) is ommitted
   for i=0,n_elements(infile)-1 do begin
      if i eq 0 then contents=(rd_tfile(infile(i),/compress))(1:*) else $
         contents=[contents,(rd_tfile(infile(i),/compress))(1:*)]
   endfor
   file=arr2str(infile)
   nrecs=n_elements(contents)
   datetime=strmid(contents,0,19)
   timeint=timstr2tim(datetime,type=3,/toint)
   sstimes=sort_index(timeint,/loud,/ss)
   timeint=timeint(sstimes)
   contents=contents(sstimes)
endif

ss=indgen(n_elements(contents))
uly_recs=0b
if keyword_set(week) then begin
   ss=sel_timrange(timeint,week=week)
   if n_elements(ss) le 1 then begin
      message,/info,'No records found for week: ' + week + ' returning...'
      return
   endif
endif

; 
nrecs=n_elements(ss)

times=timeint(ss)
data=strmid(contents(ss),19,80)
fdata=fltarr(4,nrecs)
reads,data,fdata

gbo_struct,uly_fem=uly_fem
uly_recs=replicate(uly_fem,nrecs)
uly_recs.time=times.time
uly_recs.day=times.day
uly_recs.pvelocity=reform(fdata(0,*))
uly_recs.radius=reform(fdata(1,*))
uly_recs.he_lat=reform(fdata(2,*))
uly_recs.he_lon=reform(fdata(3,*))

return
end

