function rd_selsisi_dir, infil=infil, selimg=selimg, selloc=selloc, outfil=outfil, new=new
;
;+
;NAME:
;	rd_selsisi_dir
;PURPOSE:
;	To read the SELSIS image directory file and optionally select
;	a subset of the images listed
;CALLING SEQUENCE:
;	infil = rd_selsisi_dir()
;	infil = rd_selsisi_dir(selimg='full disk h-alpha')
;	infil = rd_selsisi_dir(selloc=['hmn', 'kpno'])
;OPTIONAL KEYWORD INPUT:
;	infil	- The input file.  If not defined it is ???
;		  $DIR_GBO_SELSISI/copy_directory.lis
;	selimg	- A string array containing a list of the images to
;		  select.  Optional vaules are:
;			'Full Disk H-alpha'
;			'Full Disk Helium 10830A'
;			'Full Disk Magnetic'
;			'Full Disk Unknown'		;CaK
;			'Lrg Scale H-alpha'
;			'Lrg Scale White Light/B2'
;	selloc	- A string array containing a list of the locations to
;		  select.  Optional values are:
;			LEAR, APOL, HMN, KPNO, BOU
;	new	- If set, then check the log of all images copied over so
;		  far and only copy new files
;OUTPUT:
;	Returns a string array with the selected lines from the directory
;	listing.  The file name is the first 15 characters
;OPTIONAL KEYWORD OUTPUT:
;	outfil	- The file names of the selected files
;HISTORY:
;	Written 2-Jul-92 by M.Morrison
;-
;
;i92062802224204 Full Disk H-alpha        LEAR FULL DISK H-ALPHA APLM 28 JUN 92
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;
if (n_elements(infil) eq 0) then infil = concat_dir('$DIR_GBO_SELSISI', 'copy_directory.lis')
;
if (not file_exist(infil)) then return, ''
;
openr, lun, infil, /get_lun
lin = ' '
while not eof(lun) do begin
    readf, lun, lin
    lin = strmid(lin, 0, 80)			;trim off any comments added by WR_SELSISI_DIR
    if (n_elements(out) eq 0) then out = lin else out = [out, lin]
end
free_lun, lun
;
if (keyword_set(selimg)) then begin
    test = strupcase(strmid(out, 16, 24))
    test0 = strupcase(strmid(selimg+'                        ', 0, 24))
    ss = where_arr(test, test0)
    if (ss(0) ne -1) then out = out(ss) else out = ''
end
;
if (keyword_set(selloc)) then begin
    test = strupcase(strmid(out, 41, 4))
    test0 = strupcase(strmid(selloc+'    ', 0, 4))
    ss = where_arr(test, test0)
    if (ss(0) ne -1) then out = out(ss) else out = ''
end
;
if (keyword_set(new)) then begin
    test = strupcase(strmid(out, 0, 15))
    test0 = strupcase(strmid(rd_selsisi_dir(), 0, 15))		;read copy_directory.lis - images that have already been copied
    ok = bytarr(n_elements(test)) + 1
    ss = where_arr(test, test0)
    if (ss(0) ne -1) then ok(ss) = 0				;if in copied list, then do not copy it
    ss = where(ok)
    if (ss(0) ne -1) then out = out(ss) else out = ''
end
;
outfil = ''
if (out(0) ne '') then outfil = strmid(out, 0, 15) + '.span'
return, out
end
