function rd_soup, infil, head=head_arr, nodata=nodata, qdebug=qdebug
;+
;NAME:
;	rd_soup
;PURPOSE:
;	To read the LPARL SOUP LaPalma data files
;CALLING SEQUENCE:
;	img = rd_soup(infil)
;	img = rd_soup(infil, head=head)
;INPUT:
;	infil	- The input file name
;OPTIONAL KEYWORD INPUT:
;	nodata	- If set, do not read the data (just read the header)
;OUTPUT:
;	returns the image
;OPTIONAL KEYWORD OUTPUT:
;	head	- A structure with header information
;COMMENTS:
;	The routine currently will only work on uncompressed data files
;HISTORY:
;	Written 3-Mar-93 by M.Morrison
;	 4-Mar-93 (MDM) - Modifications and tuning it up
;	 8-Mar-93 (MDM) - Added "polarity" field
;			- Added /NODATA and /QDEBUG options
;			- Added decompression (call to Shine's decrunch)
;			- Allow an array of input file names
;	 9-Mar-93 (MDM) - Byte swapping is only needed some times(?)
;	16-Apr-93 (MDM) - Expanded the output structure to include the
;			  sequence number and frame number
;			- Deleted the original header from the structure
;-
;
img0 = 0
img = 0
n = n_elements(infil)
head0 = {rd_soup_oheader, sync_pattern: 0L, subf: 0b, source: 0b, $
	nhb: 0b, datyp: 0b, ndim: 0b, free1: 0b, $
	cbytes: bytarr(4), free: bytarr(178), dim: lonarr(16), $
	st$txt: bytarr(256)}
head = {rd_soup_i3header, time_day: ' ', time: 0l, day: 0, site: ' ', instrument: ' ', $
	coord: ' ', field: ' ', expos: 0., sum: ' ', type: ' ', $
	comments: strarr(10), $
	wave: 0l, offset: 0l, polarity: ' ', $
	file: ' ', nx: 0, ny: 0, $
	sequence: ' ', frame: 0}
	;;orig: head0}
head_arr = replicate(head, n)
;
for ifil=0,n-1 do begin
    openr, lun, infil(ifil), /get_lun
    break_file, infil(ifil), dsk_log, dir00, filnam, ext
    readu, lun, head0
    ;dec2sun, head0		;byte swap
    if (head0.sync_pattern ne 1431677610) then dec2sun, head0		;byte swap
    ;
    txt = string(head0.st$txt)
    dummy = anytim2ints( strmid(txt, 0, 23) )
    head.time_day	= strmid(txt, 0, 23)
    head.time		= dummy.time
    head.day		= dummy.day
    head.site		= strmid(txt, 24, 20)
    head.instrument	= strmid(txt, 24+21, 20)
    head.coord		= strmid(txt, 24+21+21, 35)
    head.expos		= float(strmid(txt, 24+21+21+36, 7))
    head.sum		= strmid(txt, 24+21+21+36+8, 3)
    head.field		= strmid(txt, 24+21+21+36+8+4, 10)
    head.type		= strmid(txt, 24+21+21+36+8+4+11, 4)
    line = strmid(txt, 24+21+21+36+8+4+11+5, 160)
    head.comments	= str2arr(line, delim=byte(13))
    ;
    head.wave		= long(strmid(head.comments(0),  5, 5))
    head.offset		= long(strmid(head.comments(0), 10, 5))
    head.polarity	= strmid(head.comments(0), 15, 3)
    ;
    head.file		= infil(ifil)
    head.nx		= head0.dim(0)
    head.ny		= head0.dim(1)
    ;
    p1 = strpos(filnam, 'w')
    ln = strlen(filnam)
    if (p1 eq -1) then begin
	ss = where(byte(strmid(filnam,2,100)) gt 57)
	head.sequence	= strmid(filnam, 0, ss(0)+2)	;look for first non-numeric value
    end else begin
	head.sequence	= strmid(filnam, 0, p1)
    end
    head.frame		= fix(strmid(filnam, ln-4, 4))
    ;head.orig 		= head0
    ;
    head_arr(ifil)	= head
    ;
    if (not keyword_set(nodata)) then begin
	;------ Decompress the input file - write the results into a temporary
	;       data file

	case strtrim(strlowcase(!version.os),2) of
	    'ultrix': fil_exec = 'decrunch_dec'
	    'irix':   fil_exec = 'decrunch_sgi'
	    else: begin
		    fil_exec = ''
		    print, 'The decompression program is not available for your machine.
		    print, 'Continuing assuming the file has already been decompressed'
		end
	endcase
	outfil = ''
	if (fil_exec ne '') then begin
	    fil_path = path_lib(fil_exec,/nopro)              ; Get the path name	
	    fil_path = fil_path(0)
	    outfil =  concat_dir(getenv('HOME'), 'rd_soup.temp')
	    cmd = fil_path + ' ' + infil(ifil) + ' ' + outfil
	    if (keyword_set(qdebug)) then print, cmd
	    spawn, cmd
	    free_lun, lun	;close lun from header reading portion
	    openr, lun, outfil, /get_lun
	    point_lun, lun, 512		;skip 512 bytes past the header
	end
	;
	ndim = head0.ndim
	nx = head.nx
	ny = head.ny
	img0 = intarr(nx, ny)	;temporarily hardwired to two dimensions, integer*2
	readu, lun, img0
	;
	if ((min(img0) lt -32000) or (max(img0) gt 32000)) then dec2sun, img0	;byte swapping only necessary some times?!?!?!
	;
	if ((ifil eq 0) and (n gt 1)) then begin
	    dummy = rd_soup(infil, head=head_temp, /nodata)	;read the header
								;for all files
	    nx_max = max(head_temp.nx)
	    ny_max = max(head_temp.ny)
	    img = intarr(nx_max, ny_max, n)
	end
	if (n gt 1) then img(0, 0, ifil) = img0
	if (outfil ne '') then spawn, 'rm -f ' + outfil
    end

    free_lun, lun
end
;
if (n eq 1) then return, img0 else return, img		;don't have to make a
							;copy of the image for the
							;case where only one file
							;is read
end
